@@ -97,7 +97,7 @@ class BeamSpot:
             #or to print it in the python console
             print(bs)
         """
-        return self.fit.__repr__
+        return self.fit.__repr__()
 
     def plot_y_int(self, label=""):
         """
@@ -908,7 +908,7 @@ def import_config(fname):
     try:
         with open(fname, 'rb') as f1:
             pp = dill.load(f1)
-            print("MCP parameters", pp.name, "from", fname, "imported")
+            #print("MCP parameters", pp.name, "from", fname, "imported")
     except (Exception,):
         print("Importation of", fname, "has failed")
     return pp
